@@ -229,7 +229,7 @@ class ComprehendMedicalClient(BaseClient):
     def list_entities_detection_v2_jobs(
         self,
         *,
-        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        Filter: ComprehendMedicalAsyncJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListEntitiesDetectionV2JobsResponseTypeDef:
@@ -243,7 +243,7 @@ class ComprehendMedicalClient(BaseClient):
     def list_icd10_cm_inference_jobs(
         self,
         *,
-        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        Filter: ComprehendMedicalAsyncJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListICD10CMInferenceJobsResponseTypeDef:
@@ -257,7 +257,7 @@ class ComprehendMedicalClient(BaseClient):
     def list_phi_detection_jobs(
         self,
         *,
-        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        Filter: ComprehendMedicalAsyncJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListPHIDetectionJobsResponseTypeDef:
@@ -272,7 +272,7 @@ class ComprehendMedicalClient(BaseClient):
     def list_rx_norm_inference_jobs(
         self,
         *,
-        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        Filter: ComprehendMedicalAsyncJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListRxNormInferenceJobsResponseTypeDef:
@@ -286,7 +286,7 @@ class ComprehendMedicalClient(BaseClient):
     def list_snomedct_inference_jobs(
         self,
         *,
-        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        Filter: ComprehendMedicalAsyncJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListSNOMEDCTInferenceJobsResponseTypeDef:
@@ -300,8 +300,8 @@ class ComprehendMedicalClient(BaseClient):
     def start_entities_detection_v2_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: Literal["en"],
         JobName: str = ...,
@@ -319,8 +319,8 @@ class ComprehendMedicalClient(BaseClient):
     def start_icd10_cm_inference_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: Literal["en"],
         JobName: str = ...,
@@ -338,8 +338,8 @@ class ComprehendMedicalClient(BaseClient):
     def start_phi_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: Literal["en"],
         JobName: str = ...,
@@ -356,8 +356,8 @@ class ComprehendMedicalClient(BaseClient):
     def start_rx_norm_inference_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: Literal["en"],
         JobName: str = ...,
@@ -375,8 +375,8 @@ class ComprehendMedicalClient(BaseClient):
     def start_snomedct_inference_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: Literal["en"],
         JobName: str = ...,
